==> powerdevil-5.15.0.tar.xz: powerdevil-5.15.0/daemon/powerdevilscreenbrightnesslogic.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Nikita Skovoroda <chalkerx@gmail.com>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_SCREENBRIGHNTESSLOGIC_H
#define POWERDEVIL_SCREENBRIGHNTESSLOGIC_H

#include "powerdevilbrightnesslogic.h"

namespace PowerDevil {

class ScreenBrightnessLogic : public BrightnessLogic
{

public:
    int toggled() const override;

protected:
    int calculateSteps(int valueMax) const override;

};

}

#endif // POWERDEVIL_SCREENBRIGHNTESSLOGIC_H

==> powerdevil-5.25.0.tar.xz: powerdevil-5.25.0/daemon/powerdevilscreenbrightnesslogic.h <==
/***************************************************************************
 *   Copyright (C) 2014 by Nikita Skovoroda <chalkerx@gmail.com>            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_SCREENBRIGHTNESSLOGIC_H
#define POWERDEVIL_SCREENBRIGHTNESSLOGIC_H

#include "powerdevilbrightnesslogic.h"

namespace PowerDevil {

class ScreenBrightnessLogic : public BrightnessLogic
{

public:
    int toggled() const override;

protected:
    int calculateSteps(int valueMax) const override;

};

}

#endif // POWERDEVIL_SCREENBRIGHTNESSLOGIC_H
